@@ -793,31 +793,27 @@
   rounding purposes."
   :properties ((assign 'fpprec1)))
 
-(defmvar bigfloatzero '((bigfloat simp 56.) 0 0)
-  "Bigfloat representation of 0"
+(defmvar *bigfloatzero*
+    '((bigfloat simp 56.) 0 0)
+  "Bigfloat representation of 0  Automatically updated whenever fpprec
+  is set."
   in-core)
 
-(defmvar bigfloatone  '((bigfloat simp 56.) #.(expt 2 55.) 1)
-  "Bigfloat representation of 1"
+(defmvar *bigfloatone*
+    '((bigfloat simp 56.) #.(expt 2 55.) 1)
+  "Bigfloat representation of 1.  Automatically updated whenever fpprec
+  is set."
   in-core)
 
-(defmvar bfhalf	      '((bigfloat simp 56.) #.(expt 2 55.) 0)
-  "Bigfloat representation of 1/2")
+(defmvar *bfhalf*
+    '((bigfloat simp 56.) #.(expt 2 55.) 0)
+  "Bigfloat representation of 1/2.  Automatically updated whenever fpprec
+  is set.")
 
-(defmvar bfmhalf      '((bigfloat simp 56.) #.(- (expt 2 55.)) 0)
-  "Bigfloat representation of -1/2")
-
-(defmvar bigfloat%e   '((bigfloat simp 56.) 48968212118944587. 2)
-  "Bigfloat representation of %E")
-
-(defmvar bigfloat%pi  '((bigfloat simp 56.) 56593902016227522. 2)
-  "Bigfloat representation of %pi")
-
-(defmvar bigfloat%gamma '((bigfloat simp 56.) 41592772053807304. 0)
-  "Bigfloat representation of %gamma")
-
-(defmvar bigfloat_log2 '((bigfloat simp 56.) 49946518145322874. 0)
-  "Bigfloat representation of log(2)")
+(defmvar *bfmhalf*
+    '((bigfloat simp 56.) #.(- (expt 2 55.)) 0)
+  "Bigfloat representation of -1/2.  Automatically updated whenever
+  fpprec is set.")
 
 ;; Number of bits of precision in the mantissa of newly created bigfloats.
 ;; FPPREC = ($FPPREC+1)*(Log base 2 of 10)
@@ -1692,7 +1688,6 @@
 (defvar *maxima-lispname*
   #+clisp "clisp"
   #+cmu "cmucl"
-  #+scl "scl"
   #+sbcl "sbcl"
   #+gcl "gcl"
   #+allegro "acl"
@@ -1700,7 +1695,7 @@
   #+abcl "abcl"
   #+lispworks "lispworks"
   #+ecl "ecl"
-  #-(or clisp cmu scl sbcl gcl allegro openmcl abcl lispworks ecl) "unknownlisp")
+  #-(or clisp cmu sbcl gcl allegro openmcl abcl lispworks ecl) "unknownlisp")
 
 ;;; Locations of various types of files. These variables are discussed
 ;;; in more detail in the file doc/implementation/dir_vars.txt. Since
